@@ -1,7 +1,7 @@
 package DBIx::Handler;
 use strict;
 use warnings;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use DBI 1.605;
 use DBIx::TransactionManager 1.09;
@@ -23,7 +23,8 @@ sub new {
         result_class     => $opts->{result_class}     || undef,
         on_connect_do    => $opts->{on_connect_do}    || undef,
         on_disconnect_do => $opts->{on_disconnect_do} || undef,
-        dbi_class        => $opts->{dbi_class} || "DBI",
+        no_ping          => $opts->{no_ping}          || 0,
+        dbi_class        => $opts->{dbi_class}        || "DBI",
     }, $class;
 }
 
@@ -57,6 +58,11 @@ sub dbh {
     $self->_seems_connected or $self->_connect;
 }
 
+sub _ping {
+    my ($self, $dbh) = @_;
+    $self->{no_ping} || $dbh->ping;
+}
+
 sub _seems_connected {
     my $self = shift;
 
@@ -69,7 +75,7 @@ sub _seems_connected {
         return;
     }
 
-    unless ($dbh->FETCH('Active') && $dbh->ping) {
+    unless ($dbh->FETCH('Active') && $self->_ping($dbh)) {
         $self->_in_txn_check;
         $self->_disconnect;
         return;
@@ -129,6 +135,12 @@ sub trace_ignore_if {
     $self->{trace_ignore_if};
 }
 
+sub no_ping {
+    my ($self, $enable) = @_;
+    $self->{no_ping} = $enable if defined $enable;
+    $self->{no_ping};
+}
+
 sub query {
     my ($self, $sql, @args) = @_;
 
@@ -268,6 +280,8 @@ sub txn_commit   { $_[0]->txn_manager->txn_commit   }
 
 __END__
 
+=for stopwords dbh dsn txn coderef sql
+
 =head1 NAME
 
 DBIx::Handler - fork-safe and easy transaction handling DBI handler
@@ -293,6 +307,36 @@ DBIx::Handler provide scope base transaction, fork safe dbh handling, simple.
 
 get database handling instance.
 
+Options:
+
+=over 4
+
+=item on_connect_do : CodeRef|ArrayRef[Str]|Str
+
+=item on_disconnect_do : CodeRef|ArrayRef[Str]|Str
+
+Execute SQL or CodeRef when connected/disconnected.
+
+=item result_class : ClassName
+
+This is a C<query> method's result class.
+If this value is defined, C<$result_class->new($handler, $sth)> is called in C<query()> and C<query()> returns the instance.
+
+=item trace_query : Bool
+
+Enables to inject a caller information as SQL comment.
+
+=item trace_ignore_if : CodeRef
+
+Ignore to inject the SQL comment when trace_ignore_if's return value is true.
+
+=item no_ping : Bool
+
+By default, ping before each executing query.
+If it affect performance then you can set to true for ping stopping.
+
+=back
+
 =item my $handler = DBIx::Handler->connect($dsn, $user, $pass, $opts);
 
 connect method is alias for new method.
@@ -383,21 +427,27 @@ execute query. return database statement handler.
 
 =item my $sql = $handler->trace_query_set_comment($sql);
 
-inject a caller information as a sql comment to C<$sql> when trace_query is true.
+inject a caller information as a SQL comment to C<$sql> when trace_query is true.
 
-=item $handler->result_class($result_class_name);
+=back
 
-set result_class package name.
+=head2 ACCESSORS
 
-this result_class use to be create query method response object.
+The setters and the getters for options.
 
-=item $handler->trace_query($flag);
+=over 4
 
-inject sql comment when trace_query is true.
+=item result_class
 
-=item $handler->trace_ignore_if($callback);
+=item trace_query
 
-ignore to inject sql comment when trace_ignore_if's return value is true.
+=item trace_ignore_if
+
+=item no_ping
+
+=item on_connect_do
+
+=item on_disconnect_do
 
 =back
 
